BottomNavigationItem class

Constructors

BottomNavigationItem({Color? color, String? title, Duration? duration, required Widget activeIcon, required Widget inActiveIcon, required TickerProvider vSync})
Animation Object to design and the animation as you wish.

Properties

controller → AnimationController
Controller object to specify the duration of the animation and register the TickerProvider for the root widget.
final
hashCode → int
The hash code for this object.
no setterinherited
item → BottomNavigationBarItem
The main navigation icon view.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited