ScaffoldGlobalBottomNavigation class

Inheritance

Constructors

ScaffoldGlobalBottomNavigation({Key? key, PreferredSizeWidget? appBar, required List<Widget> listOfChild, required List<BottomNavigationItem> listOfBottomNavigationItem, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, FloatingActionButtonAnimator? floatingActionButtonAnimator, List<Widget>? persistentFooterButtons, Widget? drawer, Widget? endDrawer, Widget? bottomNavigationBar, Widget? bottomSheet, Color? backgroundColor, bool? resizeToAvoidBottomInset, bool primary = true, DragStartBehavior drawerDragStartBehavior = DragStartBehavior.start, bool extendBody = false, bool extendBodyBehindAppBar = false, Color? drawerScrimColor, double? drawerEdgeDragWidth, bool drawerEnableOpenDragGesture = true, bool endDrawerEnableOpenDragGesture = true})
const

Properties

appBar → PreferredSizeWidget?
An app bar to display at the top of the scaffold.
final
backgroundColor → Color?
The color of the Material widget that underlies the entire Scaffold.
final
bottomNavigationBar → Widget?
A bottom navigation bar to display at the bottom of the scaffold.
final
bottomSheet → Widget?
The persistent bottom sheet to display.
final
drawer → Widget?
A panel displayed to the side of the body, often hidden on mobile devices. Swipes in from either left-to-right (TextDirection.ltr) or right-to-left (TextDirection.rtl)
final
drawerDragStartBehavior → DragStartBehavior
final
drawerEdgeDragWidth → double?
The width of the area within which a horizontal swipe will open the drawer.
final
drawerEnableOpenDragGesture → bool
Determines if the Scaffold.drawer can be opened with a drag gesture.
final
drawerScrimColor → Color?
The color to use for the scrim that obscures primary content while a drawer is open.
final
endDrawer → Widget?
A panel displayed to the side of the body, often hidden on mobile devices. Swipes in from right-to-left (TextDirection.ltr) or left-to-right (TextDirection.rtl)
final
endDrawerEnableOpenDragGesture → bool
Determines if the Scaffold.endDrawer can be opened with a drag gesture.
final
extendBody → bool
final
extendBodyBehindAppBar → bool
If true, and an appBar is specified, then the height of the body is
final
floatingActionButton → Widget?
A button displayed floating above body, in the bottom right corner.
final
floatingActionButtonAnimator → FloatingActionButtonAnimator?
Animator to move the floatingActionButton to a new floatingActionButtonLocation.
final
floatingActionButtonLocation → FloatingActionButtonLocation?
Responsible for determining where the floatingActionButton should go.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listOfBottomNavigationItem → List<BottomNavigationItem>
The primary content of the scaffold.
final
listOfChild → List<Widget>
The primary content of the scaffold.
final
persistentFooterButtons → List<Widget>?
A set of buttons that are displayed at the bottom of the scaffold.
final
primary → bool
Whether this scaffold is being displayed at the top of the screen.
final
resizeToAvoidBottomInset → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ScaffoldGlobalBottomNavigationState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited